@@ -8,7 +8,7 @@ use warnings;
 use Carp qw();
 use File::Copy qw();
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 sub _keywords { qw(
     install_hook
@@ -53,7 +53,8 @@ Git::Repository::Plugin::Hooks - Work with hooks in a Git::Repository
 
 =head1 DESCRIPTION
 
-Git::Repository::Plugin::Hooks is ...
+Git::Repository::Plugin::Hooks adds the C<install_hook> and C<hook_path>
+methods to a Git::Repository.
 
 =head1 METHODS
 
@@ -61,6 +62,11 @@ Git::Repository::Plugin::Hooks is ...
 
 Install a C<$target>, e.g. 'pre-receive', hook into the repository.
 
+=head2 hook_path($target)
+
+Returns the path to a hook of the type specified by C<$target>.  See C<man
+githooks> for examples, e.g. C<pre-commit>.
+
 =head1 LICENSE
 
 Copyright (C) Nathaniel Nutter.
